@@ -155,6 +155,24 @@ class KitsuAPIWrapper(flow.Object):
         
         return task
     
+    def get_shot_task(self, sequence_name, shot_name, task_type_name):
+        task = None
+        shot = self.get_shot_data(shot_name, sequence_name)
+
+        if shot is not None:
+            task = self.get_task(shot, task_type_name)
+        
+        return task
+    
+    def get_shot_task_status_name(self, sequence_name, shot_name, task_type_name):
+        task = self.get_shot_task(sequence_name, shot_name, task_type_name)
+        status = None
+        
+        if task is not None:
+            status = task['task_status']['name']
+        
+        return status
+    
     def get_task_statutes(self):
         task_statuses = gazu.task.all_task_statuses()
         return [ts['name'] for ts in task_statuses]
@@ -206,6 +224,15 @@ class KitsuAPIWrapper(flow.Object):
         
         return kitsu_id in assignees
     
+    def set_shot_task_status(self, sequence_name, shot_name, task_type_name, task_status_name, comment=''):
+        task = self.get_shot_task(sequence_name, shot_name, task_type_name)
+
+        if task is not None:
+            status = gazu.task.get_task_status_by_name(task_status_name)
+
+            if status is not None:
+                gazu.task.add_comment(task, status, comment=comment)
+    
     def upload_preview(self, kitsu_entity, task_type_name, task_status_name, file_path, comment="", user_name=None):
         # Get user
         user = self.get_user(user_name)
